@@ -1,5 +1,3 @@
-import warnings
-
 from rest_framework.filters import BaseFilterBackend
 
 
@@ -28,13 +26,3 @@ class ObjectPermissionsFilter(BaseFilterBackend):
         return get_objects_for_user(
             user, permission, queryset,
             **self.shortcut_kwargs)
-
-
-class DjangoObjectPermissionsFilter(ObjectPermissionsFilter):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        warnings.warn(
-            '`DjangoObjectPermissionsFilter` has been renamed to '
-            '`ObjectPermissionsFilter` and will be removed in the future.',
-            DeprecationWarning, stacklevel=2,
-        )
